@@ -6,6 +6,8 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #pragma once
+#include "article.h"
+#include "articlematcher.h"
 
 #include <QObject>
 
@@ -18,7 +20,6 @@ class QModelIndex;
 
 namespace Akregator
 {
-class Article;
 class ArticleModel;
 class FeedList;
 class FolderExpansionHandler;
@@ -104,4 +105,3 @@ Q_SIGNALS:
     void articleDoubleClicked(const Akregator::Article &);
 };
 } // namespace Akregator
-
