@@ -14,27 +14,18 @@
 
 #include "aboutdata.h"
 #include "actionmanagerimpl.h"
-#include "akregator-version.h"
 #include "akregator_options.h"
 #include "akregatorconfig.h"
 #include "article.h"
-#include "dummystorage/storagefactorydummyimpl.h"
 #include "feedlist.h"
-#include "fetchqueue.h"
 #include "framemanager.h"
-#include "kcoreaddons_version.h"
 #include "kernel.h"
 #include "loadfeedlistcommand.h"
 #include "mainwidget.h"
 #include "notificationmanager.h"
-#include "plugin.h"
-#include "pluginmanager.h"
-#include "storage.h"
-#include "storagefactory.h"
-#include "storagefactoryregistry.h"
+#include "storage/storage.h"
 #include "trayicon.h"
 #include "unityservicemanager.h"
-#include "utils.h"
 #include "widgets/akregatorcentralwidget.h"
 #include <KConfig>
 #include <KIO/FileCopyJob>
@@ -49,14 +40,12 @@
 #include <KJobWidgets>
 #include <KParts/Plugin>
 #include <KPluginFactory>
-#include <KService>
 #include <QSaveFile>
 #include <QTemporaryFile>
 #include <QWebEngineSettings>
 #include <kxmlguifactory.h>
 
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "akregratormigrateapplication.h"
 #endif
 #include "partadaptor.h"
@@ -68,6 +57,9 @@
 #include <QTextStream>
 #include <QTimer>
 #include <QWidget>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QWebEngineProfile>
+#endif
 
 #include <QFontDatabase>
 #include <QStandardPaths>
@@ -143,7 +135,7 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     : KParts::Part(parent)
 {
     mySelf = this;
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     AkregratorMigrateApplication migrate;
     migrate.migrate();
 #endif
@@ -151,9 +143,6 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     Part::config();
     initFonts();
 
-    setPluginLoadingMode(LoadPluginsIfEnabled);
-    setPluginInterfaceVersion(AKREGATOR_PLUGIN_INTERFACE_VERSION);
-
     setComponentName(QStringLiteral("akregator"), i18n("Akregator"));
     setXMLFile(QStringLiteral("akregator_part.rc"), true);
 
@@ -164,28 +153,9 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     QDir().mkpath(path);
     m_standardFeedList = path + QStringLiteral("/feeds.opml");
 
-    auto dummyFactory = new Backend::StorageFactoryDummyImpl();
-    if (!Backend::StorageFactoryRegistry::self()->registerFactory(dummyFactory, dummyFactory->key())) {
-        // There was already a dummy factory registered.
-        delete dummyFactory;
-    }
-    loadPlugins(QStringLiteral("storage")); // FIXME: also unload them!
-
-    m_storage = nullptr;
-    Backend::StorageFactory *storageFactory = Backend::StorageFactoryRegistry::self()->getFactory(Settings::archiveBackend());
-    if (storageFactory != nullptr) {
-        m_storage = storageFactory->createStorage(QStringList());
-    }
-
-    if (!m_storage) { // Houston, we have a problem
-        m_storage = Backend::StorageFactoryRegistry::self()->getFactory(QStringLiteral("dummy"))->createStorage(QStringList());
-
-        KMessageBox::error(parentWidget,
-                           i18n("Unable to load storage backend plugin \"%1\". No feeds are archived.", Settings::archiveBackend()),
-                           i18n("Plugin error"));
-    }
-
+    m_storage = new Backend::Storage;
     m_storage->open(true);
+
     Kernel::self()->setStorage(m_storage);
 
     m_actionManager = new ActionManagerImpl(this);
@@ -220,7 +190,6 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     connect(m_autosaveTimer, &QTimer::timeout, this, &Part::slotSaveFeedList);
     m_autosaveTimer->start(5 * 60 * 1000); // 5 minutes
 
-    loadPlugins(QStringLiteral("extension")); // FIXME: also unload them!
     if (mCentralWidget->previousSessionCrashed()) {
         mCentralWidget->needToRestoreCrashedSession();
     } else {
@@ -245,20 +214,6 @@ void Part::updateQuickSearchLineText()
     }
 }
 
-void Part::loadPlugins(const QString &type)
-{
-    const KService::List offers = PluginManager::query(QStringLiteral("[X-KDE-akregator-plugintype] == '%1'").arg(type));
-
-    for (const KService::Ptr &i : offers) {
-        Akregator::Plugin *plugin = PluginManager::createFromService(i, this);
-        if (!plugin) {
-            continue;
-        }
-        plugin->initialize();
-        plugin->insertGuiClients(this);
-    }
-}
-
 void Part::slotOnShutdown()
 {
     autoSaveProperties();
@@ -608,7 +563,8 @@ void Part::showOptions()
         if (TrayIcon::getInstance()) {
             connect(m_dialog, qOverload<>(&KCMultiDialog::configCommitted), TrayIcon::getInstance(), &TrayIcon::settingsChanged);
         }
-        const QVector<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim/kcms/akregator"));
+        const QVector<KPluginMetaData> availablePlugins =
+            KPluginMetaData::findPlugins(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kcms/akregator"));
         for (const KPluginMetaData &metaData : availablePlugins) {
             m_dialog->addModule(metaData);
         }
@@ -668,12 +624,21 @@ void Part::initFonts()
         }
         Settings::setMediumFontSize(medfs);
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::StandardFont, Settings::standardFont());
     QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::FixedFont, Settings::fixedFont());
     QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::SerifFont, Settings::serifFont());
     QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::SansSerifFont, Settings::sansSerifFont());
     QWebEngineSettings::defaultSettings()->setFontSize(QWebEngineSettings::MinimumFontSize, Settings::minimumFontSize());
     QWebEngineSettings::defaultSettings()->setFontSize(QWebEngineSettings::DefaultFontSize, Settings::mediumFontSize());
+#else
+    QWebEngineProfile::defaultProfile()->settings()->setFontFamily(QWebEngineSettings::StandardFont, Settings::standardFont());
+    QWebEngineProfile::defaultProfile()->settings()->setFontFamily(QWebEngineSettings::FixedFont, Settings::fixedFont());
+    QWebEngineProfile::defaultProfile()->settings()->setFontFamily(QWebEngineSettings::SerifFont, Settings::serifFont());
+    QWebEngineProfile::defaultProfile()->settings()->setFontFamily(QWebEngineSettings::SansSerifFont, Settings::sansSerifFont());
+    QWebEngineProfile::defaultProfile()->settings()->setFontSize(QWebEngineSettings::MinimumFontSize, Settings::minimumFontSize());
+    QWebEngineProfile::defaultProfile()->settings()->setFontSize(QWebEngineSettings::DefaultFontSize, Settings::mediumFontSize());
+#endif
 }
 
 bool Part::handleCommandLine(const QStringList &args)
