@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ ArticleHtmlWebEngineWriter::ArticleHtmlWebEngineWriter(ArticleViewerWebEngine *v
 {
 }
 
-ArticleHtmlWebEngineWriter::~ArticleHtmlWebEngineWriter()
-{
-}
+ArticleHtmlWebEngineWriter::~ArticleHtmlWebEngineWriter() = default;
 
 void ArticleHtmlWebEngineWriter::begin()
 {
