@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,9 +36,7 @@ ArticleViewerWebEnginePage::ArticleViewerWebEnginePage(QObject *parent)
     connect(this, &QWebEnginePage::loadProgress, this, &ArticleViewerWebEnginePage::onLoadProgress);
 }
 
-ArticleViewerWebEnginePage::~ArticleViewerWebEnginePage()
-{
-}
+ArticleViewerWebEnginePage::~ArticleViewerWebEnginePage() = default;
 
 bool ArticleViewerWebEnginePage::acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame)
 {
