@@ -7,11 +7,12 @@
 #include "articleviewerwebenginewidgetng.h"
 #include "akregator_debug.h"
 #include <KActionCollection>
-#include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <MessageViewer/ViewerPluginToolManager>
 #include <QVBoxLayout>
+#include <kio_version.h>
 #if KPIMTEXTEDIT_TEXT_TO_SPEECH
 #include <kpimtextedit/texttospeechwidget.h>
 #endif
@@ -27,7 +28,8 @@
 #include <QPrinter>
 
 using namespace Akregator;
-template<typename Arg, typename R, typename C> struct InvokeWrapper {
+template<typename Arg, typename R, typename C>
+struct InvokeWrapper {
     R *receiver;
     void (C::*memberFun)(Arg);
     void operator()(Arg result)
@@ -36,7 +38,8 @@ template<typename Arg, typename R, typename C> struct InvokeWrapper {
     }
 };
 
-template<typename Arg, typename R, typename C> InvokeWrapper<Arg, R, C> invoke(R *receiver, void (C::*memberFun)(Arg))
+template<typename Arg, typename R, typename C>
+InvokeWrapper<Arg, R, C> invoke(R *receiver, void (C::*memberFun)(Arg))
 {
     InvokeWrapper<Arg, R, C> wrapper = {receiver, memberFun};
     return wrapper;
@@ -138,7 +141,11 @@ void ArticleViewerWebEngineWidgetNg::printRequested(QWebEnginePage *page)
         return;
     }
     delete dialog;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     page->print(mCurrentPrinter, invoke(this, &ArticleViewerWebEngineWidgetNg::slotHandlePagePrinted));
+#else
+#pragma "Fix port printing"
+#endif
 }
 
 void ArticleViewerWebEngineWidgetNg::slotHandlePagePrinted(bool result)
@@ -175,7 +182,7 @@ void ArticleViewerWebEngineWidgetNg::slotOpenInBrowser()
         job->start();
     } else {
         auto job = new KIO::OpenUrlJob(currentUrl, QStringLiteral("text/html"));
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
         job->setDeleteTemporaryFile(true);
         job->start();
     }
@@ -189,7 +196,7 @@ void ArticleViewerWebEngineWidgetNg::slotExportHtmlPageFailed()
 void ArticleViewerWebEngineWidgetNg::slotExportHtmlPageSuccess(const QString &filename)
 {
     auto job = new KIO::OpenUrlJob(QUrl::fromLocalFile(filename), QStringLiteral("text/html"));
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
     job->setDeleteTemporaryFile(true);
     job->start();
 }
