@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,6 +8,8 @@
 
 #include "akregator_export.h"
 #include "articleviewerwebengine.h"
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
+
 #include <QWidget>
 class QPrinter;
 class KActionCollection;
@@ -55,7 +57,9 @@ private:
     void printRequested(QWebEnginePage *page);
     WebEngineViewer::FindBarWebEngineView *mFindBarWebView = nullptr;
     ArticleViewerWebEngine *mArticleViewerNg = nullptr;
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     KPIMTextEdit::TextToSpeechWidget *const mTextToSpeechWidget;
+#endif
     KPIMTextEdit::SlideContainer *const mSliderContainer;
     WebEngineViewer::TrackingWarningWidget *const mTrackingWarningWidget;
     QPrinter *mCurrentPrinter = nullptr;
