@@ -26,12 +26,12 @@
 
 using namespace Akregator;
 
-class Q_DECL_HIDDEN CreateFeedCommand::Private
+class Akregator::CreateFeedCommandPrivate
 {
     CreateFeedCommand *const q;
 
 public:
-    explicit Private(CreateFeedCommand *qq);
+    explicit CreateFeedCommandPrivate(CreateFeedCommand *qq);
 
     void doCreate();
 
@@ -44,17 +44,16 @@ public:
     bool m_autoexec = false;
 };
 
-CreateFeedCommand::Private::Private(CreateFeedCommand *qq)
+CreateFeedCommandPrivate::CreateFeedCommandPrivate(CreateFeedCommand *qq)
     : q(qq)
     , m_rootFolder(nullptr)
     , m_subscriptionListView(nullptr)
     , m_parentFolder(nullptr)
     , m_after(nullptr)
-    , m_autoexec(false)
 {
 }
 
-void CreateFeedCommand::Private::doCreate()
+void CreateFeedCommandPrivate::doCreate()
 {
     Q_ASSERT(m_rootFolder);
     Q_ASSERT(m_subscriptionListView);
@@ -124,15 +123,12 @@ void CreateFeedCommand::Private::doCreate()
 
 CreateFeedCommand::CreateFeedCommand(MainWidget *parent)
     : Command(parent)
-    , d(new Private(this))
+    , d(new CreateFeedCommandPrivate(this))
 {
     d->m_parent = parent;
 }
 
-CreateFeedCommand::~CreateFeedCommand()
-{
-    delete d;
-}
+CreateFeedCommand::~CreateFeedCommand() = default;
 
 void CreateFeedCommand::setSubscriptionListView(SubscriptionListView *view)
 {
