@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,9 +22,7 @@ ArticleGrantleeObject::ArticleGrantleeObject(const Article &article, ArticleForm
 {
 }
 
-ArticleGrantleeObject::~ArticleGrantleeObject()
-{
-}
+ArticleGrantleeObject::~ArticleGrantleeObject() = default;
 
 ArticleGrantleeObject::ArticleStatus ArticleGrantleeObject::articleStatus() const
 {
